@@ -1,7 +1,6 @@
 #include <sys/types.h>
 
 #include <ctype.h>
-#include <err.h>
 #include <errno.h>
 #include <limits.h>
 #include <stdarg.h>
@@ -49,10 +48,11 @@ parseuri(const char *s, struct uri *u, int rel)
 	/* IPv6 address */
 	if (*p == '[') {
 		/* bracket not found or host too long */
-		if (!(b = strchr(p, ']')) || (size_t)(b - p) >= (ssize_t)sizeof(u->host))
+		if (!(b = strchr(p, ']')) || (size_t)(b - p) < 3 ||
+		    (size_t)(b - p) >= sizeof(u->host))
 			return -1;
-		memcpy(u->host, p + 1, b - p - 1);
-		u->host[b - p - 1] = '\0';
+		memcpy(u->host, p, b - p + 1);
+		u->host[b - p + 1] = '\0';
 		p = b + 1;
 	} else {
 		/* domain / host part, skip until port, path or end. */
@@ -98,7 +98,7 @@ encodeuri(char *buf, size_t bufsiz, const char *s)
 	size_t i, b;
 
 	for (i = 0, b = 0; s[i]; i++) {
-		if ((int)s[i] == ' ' ||
+		if (s[i] == ' ' ||
 		    (unsigned char)s[i] > 127 ||
 		    iscntrl((unsigned char)s[i])) {
 			if (b + 3 >= bufsiz)
@@ -126,7 +126,7 @@ absuri(char *buf, size_t bufsiz, const char *link, const char *base)
 {
 	struct uri ulink, ubase;
 	char tmp[4096], *host, *p, *port;
-	int r = -1, c;
+	int c, r;
 	size_t i;
 
 	buf[0] = '\0';
@@ -149,7 +149,7 @@ absuri(char *buf, size_t bufsiz, const char *link, const char *base)
 		host,
 		port[0] ? ":" : "",
 		port);
-	if (r == -1 || (size_t)r >= sizeof(tmp))
+	if (r < 0 || (size_t)r >= sizeof(tmp))
 		return -1; /* error or truncation */
 
 	/* relative to root */
@@ -226,8 +226,8 @@ strtotime(const char *s, time_t *t)
 void
 xmlencode(const char *s, FILE *fp)
 {
-	for (; *s; s++) {
-		switch(*s) {
+	for (; *s; ++s) {
+		switch (*s) {
 		case '<':  fputs("&lt;",   fp); break;
 		case '>':  fputs("&gt;",   fp); break;
 		case '\'': fputs("&#39;",  fp); break;
