@@ -31,7 +31,7 @@ struct uri {
 
 enum {
 	FieldUnixTimestamp = 0, FieldTitle, FieldLink, FieldContent,
-	FieldContentType, FieldId, FieldAuthor, FieldLast
+	FieldContentType, FieldId, FieldAuthor, FieldEnclosure, FieldLast
 };
 
 int     absuri(char *, size_t, const char *, const char *);
