@@ -1,3 +1,6 @@
+#ifndef _XML_H
+#define _XML_H
+
 typedef struct xmlparser {
 	/* handlers */
 	void (*xmlattr)(struct xmlparser *, const char *, size_t,
@@ -23,7 +26,15 @@ typedef struct xmlparser {
 	void (*xmltagstartparsed)(struct xmlparser *, const char *,
 	      size_t, int);
 
+#ifndef GETNEXT
+	/* GETNEXT overridden for sfeed to reduce function call overhead and
+	   further context optimizations. */
+	#define GETNEXT getchar
+#if 0
+	#define GETNEXT (x)->getnext
 	int (*getnext)(void);
+#endif
+#endif
 
 	/* current tag */
 	char tag[1024];
@@ -31,14 +42,11 @@ typedef struct xmlparser {
 	/* current tag is in short form ? <tag /> */
 	int isshorttag;
 	/* current attribute name */
-	char name[256];
+	char name[1024];
 	/* data buffer used for tag data, cdata and attribute data */
 	char data[BUFSIZ];
 } XMLParser;
 
-int     xml_codepointtoutf8(uint32_t, uint32_t *);
-ssize_t xml_entitytostr(const char *, char *, size_t);
-ssize_t xml_namedentitytostr(const char *, char *, size_t);
-ssize_t xml_numericentitytostr(const char *, char *, size_t);
-
-void    xml_parse(XMLParser *);
+int xml_entitytostr(const char *, char *, size_t);
+void xml_parse(XMLParser *);
+#endif
